@@ -15,7 +15,7 @@ use File::chdir;
 use Path::Tiny;
 use YAML::Syck;
 
-our $VERSION = version->new('0.1.0');
+our $VERSION = version->new('0.1.1');
 
 has [qw/ defaults options /] => (
     is => 'rw',
@@ -87,7 +87,9 @@ sub session_dir {
 sub env {
     my ( $self, $name, $dir, $config ) = @_;
 
-    $dir    ||= path( $ENV{VTIDE_DIR} || '.' ) || path( $dir || '.' )->absolute;
+    $dir    ||= path( $ENV{VTIDE_DIR} || '.' )->absolute;
+    $dir = path($dir);
+
     $config ||= $ENV{VTIDE_CONFIG} || $dir->path( '.vtide.yml' );
     $name   ||= $ENV{VTIDE_NAME}
         || $self->defaults->{name}
@@ -148,7 +150,7 @@ App::VTide::Command - Base class for VTide sub commands
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command version 0.1.0
+This documentation refers to App::VTide::Command version 0.1.1
 
 =head1 SYNOPSIS
 
